@@ -6,7 +6,7 @@ from pandas import DataFrame, Series
 from scipy.optimize import least_squares
 import warnings
 
-def calculate_amplitude_etr(fo, fm, sigma, par, alpha_phase=True, light_independent=True, dark_sigma=False, etrmax_fitting=True, serodio_sigma=False, light_step_size=None, last_steps_average=False, skip_first_light_step=False, outlier_multiplier=3, return_data=False, bounds=True, alpha_lims=[0,4], etrmax_lims=[0,2000], method='trf', loss='soft_l1', f_scale=0.1, max_nfev=None, xtol=1e-9):
+def calculate_amplitude_etr(fo, fm, sigma, par, alpha_phase=True, light_independent=True, dark_sigma=False, etrmax_fitting=True, serodio_sigma=False, light_step_size=None, last_steps_average=False, outlier_multiplier=3, return_data=False, bounds=True, alpha_lims=[0,4], etrmax_lims=[0,2000], method='trf', loss='soft_l1', f_scale=0.1, max_nfev=None, xtol=1e-9):
       
 	"""
 	
@@ -36,8 +36,6 @@ def calculate_amplitude_etr(fo, fm, sigma, par, alpha_phase=True, light_independ
 		The number of measurements for initial light step.
 	last_steps_average : bool, default=False,
 		If True, means will be created from the last 3 measurements per light step. Else, mean will be created from entire light step excluding outliers.
-	skip_first_light_step : bool, default=False,
-		If True, will skip the first light step in cases of large changes in F\ :sub:`v`/F\ :sub:`m` between first and second light step for performing light independent calculations.
 	outlier_multiplier : int, default=3
 		The multiplier to apply to the standard deviation for determining the upper and lower limits.
 	return_data : bool, default=False
@@ -165,13 +163,7 @@ def calculate_amplitude_etr(fo, fm, sigma, par, alpha_phase=True, light_independ
 
 	if light_step_size == 1:
 		if light_independent:
-			if skip_first_light_step:
-				etr = fvfm / fvfm[1]
-
-				print('Skipping first light step')
-
-			else:	
-				etr = fvfm / fvfm[0]
+			etr = fvfm / fvfm[0]
 		else:
 			if dark_sigma:
 				etr = (par * mean(sigma[0]) * (fvfm / mean(fvfm[0]))) * 6.022e-3
