@@ -78,7 +78,7 @@ def correct_fire_instrument_bias(df, pos=1, sat_len=100):
     
     """
     
-    Corrects for instrumentation bias in the relaxation phase by calculating difference between flashlet 0 the relaxation phase & flashlet[pos].
+    Corrects for instrumentation bias in the relaxation phase by calculating difference between flashlet 0 of the relaxation phase & flashlet[pos].
     This bias is then added to the relaxation phase.
 
     Parameters
@@ -86,7 +86,7 @@ def correct_fire_instrument_bias(df, pos=1, sat_len=100):
     df : pandas.DataFrame 
         A dataframe of the raw data, can either be imported from pandas.read_csv or the output from phyto_photo_utils.load
     pos : int, default=1
-     	The flashlet number after the start of the phase, either saturation or relaxation, to calculate difference between.
+     	The flashlet number after the start of the relaxation phase, to calculate difference between.
     sat_len : int, default=100
      	The length of saturation measurements.
 
@@ -119,7 +119,7 @@ def correct_fire_instrument_bias(df, pos=1, sat_len=100):
     flevel_corr = array(ycorr)
     flevel_corr = reshape(flevel_corr, (flevel_corr.shape[0] * flevel_corr.shape[1]))
     
-    # Replace fluorescence yield in DataFrame with bias corrected data 
+    # Replace fluorescence level in DataFrame with bias corrected data 
     df['flevel'] = flevel_corr
     
     return df
@@ -127,7 +127,7 @@ def correct_fire_instrument_bias(df, pos=1, sat_len=100):
 def calculate_blank_FastOcean(file_, seq_len=100, delimiter=','):
      
     """
-    Calculates the blank by averaging the fluorescence yield for the saturation phase.
+    Calculates the blank by averaging the fluorescence level for the saturation phase.
 
     Parameters
     ----------
@@ -148,13 +148,13 @@ def calculate_blank_FastOcean(file_, seq_len=100, delimiter=','):
     >>> ppu.calculate_blank_FastOcean(file_, seq_len=100)
     """
 
-    df = read_csv(file_, skiprows=26, nrows=2, header=None, delimiter=delimiter)
+    df = read_csv(file_, skiprows=26, nrows=2, header=None, delimiter=delimiter, encoding='latin1')
     df = df.iloc[:,2:].T
     df.columns = ['date', 'time']
     df['datetime'] = to_datetime(df.date.values+' '+df.time.values)
     df = df.drop(columns=['date','time'])
 
-    res = read_csv(file_, skiprows=43, nrows=seq_len, header=None, delimiter=delimiter)
+    res = read_csv(file_, skiprows=43, nrows=seq_len, header=None, delimiter=delimiter, encoding='latin1')
     res = res.iloc[:,2:]
     res = res.agg(['mean','std']).T
     res.columns = ['blank_mean', 'blank_stdev']
@@ -167,7 +167,7 @@ def calculate_blank_FastOcean(file_, seq_len=100, delimiter=','):
 def calculate_blank_FIRe(file_):
 
     """
-    Calculates the blank by averaging the fluorescence yield for the saturation phase.
+    Calculates the blank by averaging the fluorescence level for the saturation phase.
 
     Parameters
     ----------
